@@ -390,8 +390,8 @@ class TransmitterEntry(models.Model):
     def __str__(self):
         return self.description
 
-    # see https://github.com/PyCQA/pylint-django/issues/94 for why W0221
-    def save(self, *args, **kwargs):  # pylint: disable=W0221
+    # see https://github.com/PyCQA/pylint-django/issues/94
+    def save(self, *args, **kwargs):  # pylint: disable=W0222
         # this assignment is needed to preserve changes made to a Transmitter
         # through the admin UI
         self.id = None  # pylint: disable=C0103, W0201
@@ -570,6 +570,7 @@ class DemodData(models.Model):
     app_source = models.CharField(
         choices=list(zip(DATA_SOURCES, DATA_SOURCES)), max_length=7, default='sids'
     )
+    observation_id = models.IntegerField(blank=True, null=True)
     data_id = models.PositiveIntegerField(blank=True, null=True)
     payload_frame = models.FileField(upload_to=_name_payload_frame, blank=True, null=True)
     payload_decoded = models.TextField(blank=True)
@@ -584,6 +585,7 @@ class DemodData(models.Model):
     )
     is_decoded = models.BooleanField(default=False, db_index=True)
     timestamp = models.DateTimeField(null=True, db_index=True)
+    version = models.CharField(max_length=45, blank=True)
 
     class Meta:
         ordering = ['-timestamp']
@@ -606,6 +608,8 @@ class DemodData(models.Model):
                 }
             )
             return None
+        except ValueError:  # unlikely to happen in prod, but if an entry is made without a file
+            return None
 
 
 class ExportedFrameset(models.Model):
