@@ -35,6 +35,7 @@ THIRD_PARTY_APPS = (
     'bootstrap_modal_forms',
     'rest_framework',
     'rest_framework.authtoken',
+    'drf_spectacular',
     'django_countries',
     'django_filters',
     'fontawesome_5',
@@ -54,13 +55,13 @@ LOCAL_APPS = (
 if DEBUG:
     DJANGO_APPS += ('debug_toolbar', )
     DEBUG_TOOLBAR_CONFIG = {
-        'SHOW_TOOLBAR_CALLBACK':
-        lambda request: request.environ.get('SERVER_NAME', None) != 'testserver',
+        'SHOW_TOOLBAR_CALLBACK': lambda request: request.environ.get('SERVER_NAME', None) !=
+        'testserver',
     }
 
 if AUTH0:
     THIRD_PARTY_APPS += ('social_django', )
-    LOCAL_APPS += ('auth0login', )
+    # LOCAL_APPS += ('auth0login', )
 
 INSTALLED_APPS = DJANGO_APPS + THIRD_PARTY_APPS + LOCAL_APPS
 
@@ -97,8 +98,9 @@ SERVER_EMAIL = DEFAULT_FROM_EMAIL
 # Cache
 CACHES = {
     'default': {
-        'BACKEND':
-        config('CACHE_BACKEND', default='django.core.cache.backends.locmem.LocMemCache'),
+        'BACKEND': config(
+            'CACHE_BACKEND', default='django.core.cache.backends.locmem.LocMemCache'
+        ),
         'LOCATION': config('CACHE_LOCATION', default='unique-location'),
         'OPTIONS': {
             'MAX_ENTRIES': 5000,
@@ -185,7 +187,8 @@ WSGI_APPLICATION = 'db.wsgi.application'
 # Auth
 AUTHENTICATION_BACKENDS = ('django.contrib.auth.backends.ModelBackend', )
 if AUTH0:
-    AUTHENTICATION_BACKENDS += ('auth0login.auth0backend.Auth0', )
+    # AUTHENTICATION_BACKENDS += ('auth0login.auth0backend.Auth0', )
+    AUTHENTICATION_BACKENDS += ('social_core.backends.auth0.Auth0OAuth2', )
 
 ACCOUNT_AUTHENTICATION_METHOD = 'username'
 ACCOUNT_EMAIL_REQUIRED = True
@@ -271,13 +274,110 @@ REDIS_CONNECT_RETRY = True
 
 # API
 REST_FRAMEWORK = {
-    'DEFAULT_PERMISSION_CLASSES':
-    ('rest_framework.permissions.DjangoModelPermissionsOrAnonReadOnly', ),
+    'DEFAULT_PERMISSION_CLASSES': (
+        'rest_framework.permissions.DjangoModelPermissionsOrAnonReadOnly',
+    ),
     'DEFAULT_AUTHENTICATION_CLASSES': [
         'rest_framework.authentication.TokenAuthentication',
         'rest_framework.authentication.SessionAuthentication'
     ],
-    'DEFAULT_FILTER_BACKENDS': ('django_filters.rest_framework.DjangoFilterBackend', )
+    'DEFAULT_FILTER_BACKENDS': ('django_filters.rest_framework.DjangoFilterBackend', ),
+    'DEFAULT_SCHEMA_CLASS': 'drf_spectacular.openapi.AutoSchema',
+}
+
+SPECTACULAR_SETTINGS = {
+    'SCHEMA_PATH_PREFIX': r'/api',
+    'DEFAULT_GENERATOR_CLASS': 'drf_spectacular.generators.SchemaGenerator',
+
+    # Configuration for serving the schema with SpectacularAPIView
+    'SERVE_URLCONF': None,
+    'SERVE_PUBLIC': True,
+    'SERVE_INCLUDE_SCHEMA': False,
+    'SERVE_PERMISSIONS': ['rest_framework.permissions.AllowAny'],
+
+    # available SwaggerUI configuration parameters
+    # https://swagger.io/docs/open-source-tools/swagger-ui/usage/configuration/
+    'SWAGGER_UI_SETTINGS': {
+        'deepLinking': True,
+        'persistAuthorization': True,
+        'displayOperationId': True,
+    },
+
+    # we pull swagger-ui in via npm, as opposed to using their cdn
+    'SWAGGER_UI_DIST': STATIC_URL + 'lib/swagger-ui-dist',
+    'SWAGGER_UI_FAVICON_HREF': STATIC_URL + 'favicon.ico',
+    'TITLE': 'SatNOGS DB',
+    'DESCRIPTION': 'SatNOGS DB is a crowdsourced database of details about orbital \
+                    satellites and data collected from them.',
+    'TOS': None,
+    'CONTACT': {
+        'name': 'SatNOGS Developer Chat',
+        'url': 'https://riot.im/app/#/room/#satnogs-dev:matrix.org'
+    },
+    'LICENSE': {
+        'name': 'AGPL 3.0',
+        'url': 'https://www.gnu.org/licenses/agpl-3.0.html'
+    },
+    'VERSION': '1.1',
+    'SERVERS': [
+        {
+            'url': 'https://db-dev.satnogs.org',
+            'description': 'Development server'
+        }, {
+            'url': 'https://db.satnogs.org',
+            'description': 'Production server'
+        }
+    ],
+    'PREPROCESSING_HOOKS': ['drf_spectacular.hooks.preprocess_exclude_path_format'],
+    'POSTPROCESSING_HOOKS': ['drf_spectacular.hooks.postprocess_schema_enums'],
+    'GET_MOCK_REQUEST': 'drf_spectacular.plumbing.build_mock_request',
+
+    # Tags defined in the global scope
+    'TAGS': [
+        {
+            'name': 'artifacts',
+            'description': 'IN DEVELOPMENT (BETA): Artifacts are file-formatted objects \
+                            collected from a satellite observation.'
+        },
+        {
+            'name': 'modes',
+            'description': 'Radio Frequency modulation modes (RF Modes) currently \
+                            tracked in the SatNOGS DB database',
+            'externalDocs': {
+                'description': 'RF Modes in SatNOGS Wiki',
+                'url': 'https://wiki.satnogs.org/Category:RF_Modes',
+            }
+        },
+        {
+            'name': 'satellites',
+            'description': 'Human-made orbital objects, typically with radio frequency \
+                            transmitters and/or reveivers'
+        },
+        {
+            'name': 'telemetry',
+            'description': 'Telemetry objects in the SatNOGS DB database are frames of \
+                            data collected from downlinked observations.'
+        },
+        {
+            'name': 'tle',
+            'description': 'The most recent two-line elements (TLE) in the SatNOGS DB database',
+            'externalDocs': {
+                'description': 'TLE Wikipedia doc',
+                'url': 'https://en.wikipedia.org/wiki/Two-line_element_set',
+            }
+        },
+        {
+            'name': 'transmitters',
+            'description': 'Radio Frequency (RF) transmitter entities in the SatNOGS DB \
+                            database. Transmitters in this case are inclusive of Transceivers \
+                            and Transponders'
+        },
+    ],
+    'EXTERNAL_DOCS': {
+        'url': 'https://wiki.satnogs.org',
+        'description': 'SatNOGS Wiki'
+    },
+    'COMPONENT_SPLIT_REQUEST': True
 }
 
 # Security
@@ -341,6 +441,12 @@ DATA_FETCH_DAYS = config('DATA_FETCH_DAYS', default=10, cast=int)
 MAPBOX_GEOCODE_URL = 'https://api.tiles.mapbox.com/v4/geocode/mapbox.places/'
 MAPBOX_TOKEN = config('MAPBOX_TOKEN', default='')
 
+# ZEROMQ
+ZEROMQ_SOCKET_URI = config('ZEROMQ_SOCKET_URI', default='tcp://127.0.0.1:5555')
+ZEROMQ_SOCKET_RCVTIMEO = config(
+    'ZEROMQ_SOCKET_RCVTIMEO', default='100', cast=int
+)  # Time to wait for subscriber message in ms
+
 # TLE Sources
 TLE_SOURCES_REDISTRIBUTABLE = config('TLE_SOURCES_REDISTRIBUTABLE', default='manual', cast=Csv())
 TLE_SOURCES_JSON = config('TLE_SOURCES_JSON', default='')
@@ -396,3 +502,6 @@ if ENVIRONMENT == 'dev':
     for backend in TEMPLATES:
         del backend['OPTIONS']['loaders']
         backend['APP_DIRS'] = True
+
+# for h5 artifact uploads
+DATA_UPLOAD_MAX_MEMORY_SIZE = 5242880
